## ICO Tags

Information extracted from Windows ICO (icon) and CUR (cursor) files.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 2 | ImageType | no | 1 = Icon 2 = Cursor
> 4 | ImageCount | no |
> 6 | IconDir | - | --> ICO IconDir Tags

## ICO IconDir Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ImageWidth | no |
> 1 | ImageHeight | no |
> 2 | NumColors | no |
> 4 | ColorPlanes HotspotX | no no | (ICO files) (CUR files)
> 6 | BitsPerPixel HotspotY | no no | (ICO files) (CUR files)
> 8 | ImageLength | no |

(This document generated automatically by Image::ExifTool::BuildTagLookup)
Last revised Oct 19, 2022

<-- ExifTool Tag Names